==> ros-melodic-nerian-stereo_3.6.0.orig.tar.gz: nerian-vision-software-7_1_0-src/libvisiontransfer/doc/html/search/functions_a.js <==
var searchData=
[
  ['scenescanparameters',['SceneScanParameters',['../classvisiontransfer_1_1SceneScanParameters.html#a7d0d58458f0644202d6167f8797f9ceb',1,'visiontransfer::SceneScanParameters::SceneScanParameters(const DeviceInfo &amp;device)'],['../classvisiontransfer_1_1SceneScanParameters.html#a5950c4b4c3a3d37929813f4d29fbf4af',1,'visiontransfer::SceneScanParameters::SceneScanParameters(const char *address, const char *service=&quot;7683&quot;)']]],
  ['sendimagepairasync',['sendImagePairAsync',['../classvisiontransfer_1_1AsyncTransfer.html#a17a21cbb5e22cc8e45a36cf1a2ab94e9',1,'visiontransfer::AsyncTransfer']]],
  ['setautointensitydelta',['setAutoIntensityDelta',['../classvisiontransfer_1_1SceneScanParameters.html#a478f02ef69be3c23f307e624129df0de',1,'visiontransfer::SceneScanParameters']]],
  ['setautomaxexposuretime',['setAutoMaxExposureTime',['../classvisiontransfer_1_1SceneScanParameters.html#a0a3b973c5aa3e9fb5a3f3ccff773fcb7',1,'visiontransfer::SceneScanParameters']]],
  ['setautomaxgain',['setAutoMaxGain',['../classvisiontransfer_1_1SceneScanParameters.html#ae9e33e8d813206e9fb2bc113814c0754',1,'visiontransfer::SceneScanParameters']]],
  ['setautomode',['setAutoMode',['../classvisiontransfer_1_1SceneScanParameters.html#a8cda98619a3aee2821b92e7c9bb75e38',1,'visiontransfer::SceneScanParameters']]],
  ['setautorecalibrationenabled',['setAutoRecalibrationEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#ad17a3856d66dacd9e4409d4698b0e40c',1,'visiontransfer::SceneScanParameters']]],
  ['setautoroi',['setAutoROI',['../classvisiontransfer_1_1SceneScanParameters.html#a08fd2b3b8f73f03b6b7baf5ef4ff2ced',1,'visiontransfer::SceneScanParameters']]],
  ['setautoroienabled',['setAutoROIEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#acafc662222d5fa8e25fea96e18d1050f',1,'visiontransfer::SceneScanParameters']]],
  ['setautoskippedframes',['setAutoSkippedFrames',['../classvisiontransfer_1_1SceneScanParameters.html#a3a774475974232a5bc4e18bcd16e4a08',1,'visiontransfer::SceneScanParameters']]],
  ['setautotargetframe',['setAutoTargetFrame',['../classvisiontransfer_1_1SceneScanParameters.html#a7337718e128eb2f5bf39e2cfbe5e5fd1',1,'visiontransfer::SceneScanParameters']]],
  ['setautotargetintensity',['setAutoTargetIntensity',['../classvisiontransfer_1_1SceneScanParameters.html#a68b030c66ff9f1b872bfb59cb1c927d7',1,'visiontransfer::SceneScanParameters']]],
  ['setconsistencycheckenabled',['setConsistencyCheckEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#aa155a1afcf5112f0cd8a0d78fe129d99',1,'visiontransfer::SceneScanParameters']]],
  ['setconsistencychecksensitivity',['setConsistencyCheckSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#af3759aa190437375738c61c4b8081b1b',1,'visiontransfer::SceneScanParameters']]],
  ['setdisparityoffset',['setDisparityOffset',['../classvisiontransfer_1_1SceneScanParameters.html#acbaf48c56bead0295602f367773f872a',1,'visiontransfer::SceneScanParameters']]],
  ['setdisparityrange',['setDisparityRange',['../classvisiontransfer_1_1ImagePair.html#a7db8eecdf78a2d926eac86d06aa4205c',1,'visiontransfer::ImagePair']]],
  ['setgapinterpolationenabled',['setGapInterpolationEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#af2724f77ba02731a440482e525554061',1,'visiontransfer::SceneScanParameters']]],
  ['setheight',['setHeight',['../classvisiontransfer_1_1ImagePair.html#a9f764c681db1542fc95762057c2efe20',1,'visiontransfer::ImagePair']]],
  ['setimagedisparitypair',['setImageDisparityPair',['../classvisiontransfer_1_1ImagePair.html#ab60b0f3241dd0d16ddf151d0ce840f13',1,'visiontransfer::ImagePair']]],
  ['setmanualexposuretime',['setManualExposureTime',['../classvisiontransfer_1_1SceneScanParameters.html#a87d4cf1e79680412d236c3257bc966a1',1,'visiontransfer::SceneScanParameters']]],
  ['setmanualgain',['setManualGain',['../classvisiontransfer_1_1SceneScanParameters.html#a4ce47c0292c9f3812ec3de34427f3b58',1,'visiontransfer::SceneScanParameters']]],
  ['setmaskborderpixelsenabled',['setMaskBorderPixelsEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#af06b8b506763e9e6805671a6cf1147b7',1,'visiontransfer::SceneScanParameters']]],
  ['setmaxframetimedifference',['setMaxFrameTimeDifference',['../classvisiontransfer_1_1SceneScanParameters.html#a6f3676702f3a258487e3425cc73ba483',1,'visiontransfer::SceneScanParameters']]],
  ['setnamedparameter',['setNamedParameter',['../classvisiontransfer_1_1SceneScanParameters.html#a7f2acc879b5c3ce7400075483a19ce1d',1,'visiontransfer::SceneScanParameters']]],
  ['setnoisereductionenabled',['setNoiseReductionEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a80b5bc1dbc260a13c3ef1d3f0fbc9a63',1,'visiontransfer::SceneScanParameters']]],
  ['setoperationmode',['setOperationMode',['../classvisiontransfer_1_1SceneScanParameters.html#a3b4985e338735b299e368df00253a9b5',1,'visiontransfer::SceneScanParameters']]],
  ['setpixeldata',['setPixelData',['../classvisiontransfer_1_1ImagePair.html#a7b1ddc9b08b5fb02ff98af590737fde9',1,'visiontransfer::ImagePair']]],
  ['setpixelformat',['setPixelFormat',['../classvisiontransfer_1_1ImagePair.html#a45ec98d2169254dc7418d01c6d0cf92a',1,'visiontransfer::ImagePair']]],
  ['setqmatrix',['setQMatrix',['../classvisiontransfer_1_1ImagePair.html#a110340185de0f2c0a5fedfe32a9df685',1,'visiontransfer::ImagePair']]],
  ['setrawtransferdata',['setRawTransferData',['../classvisiontransfer_1_1ImageProtocol.html#a6365aab7db6ce6791b27f7e9f6eafce8',1,'visiontransfer::ImageProtocol::setRawTransferData()'],['../classvisiontransfer_1_1ImageTransfer.html#a52c309d9bf2b96ccb2e20610791344ef',1,'visiontransfer::ImageTransfer::setRawTransferData()']]],
  ['setrawvalidbytes',['setRawValidBytes',['../classvisiontransfer_1_1ImageProtocol.html#a46794c1fb69080577a6afe812efee849',1,'visiontransfer::ImageProtocol::setRawValidBytes()'],['../classvisiontransfer_1_1ImageTransfer.html#a733d9bd0e017a8e2f1816d4111248de6',1,'visiontransfer::ImageTransfer::setRawValidBytes()']]],
  ['setrowstride',['setRowStride',['../classvisiontransfer_1_1ImagePair.html#a2ae64a8ccce63fb718680187f494c983',1,'visiontransfer::ImagePair']]],
  ['setsaveautorecalibration',['setSaveAutoRecalibration',['../classvisiontransfer_1_1SceneScanParameters.html#a550499dcf377a8ab717d4bd87718170e',1,'visiontransfer::SceneScanParameters']]],
  ['setsequencenumber',['setSequenceNumber',['../classvisiontransfer_1_1ImagePair.html#a17036d5a1636b937aae7d95fc30adacb',1,'visiontransfer::ImagePair']]],
  ['setspecklefilteriterations',['setSpeckleFilterIterations',['../classvisiontransfer_1_1SceneScanParameters.html#a94a43ffbb20efbc840db3e17730c96b8',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingedgesensitivity',['setStereoMatchingEdgeSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#ad4a1461e2d499c004e0125f8649fa763',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp1edge',['setStereoMatchingP1Edge',['../classvisiontransfer_1_1SceneScanParameters.html#a6a4d92d9ce801cf53c90dac8c1775e3d',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp1noedge',['setStereoMatchingP1NoEdge',['../classvisiontransfer_1_1SceneScanParameters.html#adfe5a8c348020031031efd1564878c61',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp2edge',['setStereoMatchingP2Edge',['../classvisiontransfer_1_1SceneScanParameters.html#a009a6e41a47f976158fd208bfc4fdbe1',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp2noedge',['setStereoMatchingP2NoEdge',['../classvisiontransfer_1_1SceneScanParameters.html#ac9ee7c8b4f5285b0c7c97d46747fd833',1,'visiontransfer::SceneScanParameters']]],
  ['setsubpixelfactor',['setSubpixelFactor',['../classvisiontransfer_1_1ImagePair.html#a7cb74194370ce2fb679f4e92af0bf8c8',1,'visiontransfer::ImagePair']]],
  ['setsubpixeloptimizationroi',['setSubpixelOptimizationROI',['../classvisiontransfer_1_1SceneScanParameters.html#a0f209c7549fc9f8cec24c130479f9339',1,'visiontransfer::SceneScanParameters']]],
  ['setsubpixeloptimizationroienabled',['setSubpixelOptimizationROIEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a54e18840db98817a797f695b1065d9da',1,'visiontransfer::SceneScanParameters']]],
  ['settexturefilterenabled',['setTextureFilterEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a4feeed602b5f94c51c23762cb0bfc3af',1,'visiontransfer::SceneScanParameters']]],
  ['settexturefiltersensitivity',['setTextureFilterSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#a8d56622c330f6de6295cc1f37bb72387',1,'visiontransfer::SceneScanParameters']]],
  ['settimestamp',['setTimestamp',['../classvisiontransfer_1_1ImagePair.html#a977ee385460acd417c42bd35a77f46f0',1,'visiontransfer::ImagePair']]],
  ['settransferdata',['setTransferData',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#a4c6fdf339799ff4ef17394cc45c39366',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settransferheader',['setTransferHeader',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#a0fd369be80452c83d5532a058676517b',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settransferimagepair',['setTransferImagePair',['../classvisiontransfer_1_1ImageProtocol.html#a6dd8d9bb07978541ea03b4a45d559764',1,'visiontransfer::ImageProtocol::setTransferImagePair()'],['../classvisiontransfer_1_1ImageTransfer.html#a969ef6bc7b75e087730268fe19033102',1,'visiontransfer::ImageTransfer::setTransferImagePair()']]],
  ['settransfervalidbytes',['setTransferValidBytes',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#a70050740d27f41a9939b43a4f5a2cd59',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settrigger0enabled',['setTrigger0Enabled',['../classvisiontransfer_1_1SceneScanParameters.html#a93435b2181cbc4f399c63398ef758674',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger0pulsewidth',['setTrigger0PulseWidth',['../classvisiontransfer_1_1SceneScanParameters.html#a63d7edd805628245d6fd6155f65a6c4d',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1enabled',['setTrigger1Enabled',['../classvisiontransfer_1_1SceneScanParameters.html#a71adf6d867815e42eca47de40c456414',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1offset',['setTrigger1Offset',['../classvisiontransfer_1_1SceneScanParameters.html#a3c61d2ca5d8c10ad266787b64ca8a8b7',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1pulsewidth',['setTrigger1PulseWidth',['../classvisiontransfer_1_1SceneScanParameters.html#a7d0981519a643065885ecaf36af1be76',1,'visiontransfer::SceneScanParameters']]],
  ['settriggerfrequency',['setTriggerFrequency',['../classvisiontransfer_1_1SceneScanParameters.html#acf85cda5fd69be6c6e4025414ce88870',1,'visiontransfer::SceneScanParameters']]],
  ['setuniquenesscheckenabled',['setUniquenessCheckEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a351292901d3e1a4768e8f4d6153c782b',1,'visiontransfer::SceneScanParameters']]],
  ['setuniquenesschecksensitivity',['setUniquenessCheckSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#a4b6455fe91fe83436dccbd79df4fbcdc',1,'visiontransfer::SceneScanParameters']]],
  ['setwidth',['setWidth',['../classvisiontransfer_1_1ImagePair.html#af8b26b5dc90a9346367c573b566ecc76',1,'visiontransfer::ImagePair']]],
  ['startservice',['startService',['../classvisiontransfer_1_1internal_1_1ClientSideDataChannelIMUBNO080.html#aa9f3de8c0c6ff0f13bab9de62f8a3701',1,'visiontransfer::internal::ClientSideDataChannelIMUBNO080::startService()'],['../classvisiontransfer_1_1internal_1_1DataChannel.html#ae3ae34aa52708797caa3e68789ea7374',1,'visiontransfer::internal::DataChannel::startService()']]]
];

==> ros-melodic-nerian-stereo_3.8.0.orig.tar.gz: nerian-vision-software-8_1_0-src/libvisiontransfer/doc/html/search/functions_a.js <==
var searchData=
[
  ['scenescanparameters',['SceneScanParameters',['../classvisiontransfer_1_1SceneScanParameters.html#a7d0d58458f0644202d6167f8797f9ceb',1,'visiontransfer::SceneScanParameters::SceneScanParameters(const DeviceInfo &amp;device)'],['../classvisiontransfer_1_1SceneScanParameters.html#a5950c4b4c3a3d37929813f4d29fbf4af',1,'visiontransfer::SceneScanParameters::SceneScanParameters(const char *address, const char *service=&quot;7683&quot;)']]],
  ['sendimagesetasync',['sendImageSetAsync',['../classvisiontransfer_1_1AsyncTransfer.html#a9b437b9da1c071d1832f4ae8fa8536c7',1,'visiontransfer::AsyncTransfer']]],
  ['setautointensitydelta',['setAutoIntensityDelta',['../classvisiontransfer_1_1SceneScanParameters.html#a478f02ef69be3c23f307e624129df0de',1,'visiontransfer::SceneScanParameters']]],
  ['setautomaxexposuretime',['setAutoMaxExposureTime',['../classvisiontransfer_1_1SceneScanParameters.html#a0a3b973c5aa3e9fb5a3f3ccff773fcb7',1,'visiontransfer::SceneScanParameters']]],
  ['setautomaxgain',['setAutoMaxGain',['../classvisiontransfer_1_1SceneScanParameters.html#ae9e33e8d813206e9fb2bc113814c0754',1,'visiontransfer::SceneScanParameters']]],
  ['setautomode',['setAutoMode',['../classvisiontransfer_1_1SceneScanParameters.html#a8cda98619a3aee2821b92e7c9bb75e38',1,'visiontransfer::SceneScanParameters']]],
  ['setautorecalibrationenabled',['setAutoRecalibrationEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#ad17a3856d66dacd9e4409d4698b0e40c',1,'visiontransfer::SceneScanParameters']]],
  ['setautoroi',['setAutoROI',['../classvisiontransfer_1_1SceneScanParameters.html#a08fd2b3b8f73f03b6b7baf5ef4ff2ced',1,'visiontransfer::SceneScanParameters']]],
  ['setautoroienabled',['setAutoROIEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#acafc662222d5fa8e25fea96e18d1050f',1,'visiontransfer::SceneScanParameters']]],
  ['setautoskippedframes',['setAutoSkippedFrames',['../classvisiontransfer_1_1SceneScanParameters.html#a3a774475974232a5bc4e18bcd16e4a08',1,'visiontransfer::SceneScanParameters']]],
  ['setautotargetframe',['setAutoTargetFrame',['../classvisiontransfer_1_1SceneScanParameters.html#a7337718e128eb2f5bf39e2cfbe5e5fd1',1,'visiontransfer::SceneScanParameters']]],
  ['setautotargetintensity',['setAutoTargetIntensity',['../classvisiontransfer_1_1SceneScanParameters.html#a68b030c66ff9f1b872bfb59cb1c927d7',1,'visiontransfer::SceneScanParameters']]],
  ['setconsistencycheckenabled',['setConsistencyCheckEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#aa155a1afcf5112f0cd8a0d78fe129d99',1,'visiontransfer::SceneScanParameters']]],
  ['setconsistencychecksensitivity',['setConsistencyCheckSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#af3759aa190437375738c61c4b8081b1b',1,'visiontransfer::SceneScanParameters']]],
  ['setdisparityoffset',['setDisparityOffset',['../classvisiontransfer_1_1SceneScanParameters.html#acbaf48c56bead0295602f367773f872a',1,'visiontransfer::SceneScanParameters']]],
  ['setdisparityrange',['setDisparityRange',['../classvisiontransfer_1_1ImageSet.html#a82889f5861a493ffd9c95583cfdfb790',1,'visiontransfer::ImageSet']]],
  ['setgapinterpolationenabled',['setGapInterpolationEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#af2724f77ba02731a440482e525554061',1,'visiontransfer::SceneScanParameters']]],
  ['setheight',['setHeight',['../classvisiontransfer_1_1ImageSet.html#a9fae43233dded7e65289b44b363585d5',1,'visiontransfer::ImageSet']]],
  ['setindexof',['setIndexOf',['../classvisiontransfer_1_1ImageSet.html#ad9c94529b141b165ab1c71c414431678',1,'visiontransfer::ImageSet']]],
  ['setmanualexposuretime',['setManualExposureTime',['../classvisiontransfer_1_1SceneScanParameters.html#a87d4cf1e79680412d236c3257bc966a1',1,'visiontransfer::SceneScanParameters']]],
  ['setmanualgain',['setManualGain',['../classvisiontransfer_1_1SceneScanParameters.html#a4ce47c0292c9f3812ec3de34427f3b58',1,'visiontransfer::SceneScanParameters']]],
  ['setmaskborderpixelsenabled',['setMaskBorderPixelsEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#af06b8b506763e9e6805671a6cf1147b7',1,'visiontransfer::SceneScanParameters']]],
  ['setmaxframetimedifference',['setMaxFrameTimeDifference',['../classvisiontransfer_1_1SceneScanParameters.html#a6f3676702f3a258487e3425cc73ba483',1,'visiontransfer::SceneScanParameters']]],
  ['setnamedparameter',['setNamedParameter',['../classvisiontransfer_1_1SceneScanParameters.html#a7f2acc879b5c3ce7400075483a19ce1d',1,'visiontransfer::SceneScanParameters']]],
  ['setnoisereductionenabled',['setNoiseReductionEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a80b5bc1dbc260a13c3ef1d3f0fbc9a63',1,'visiontransfer::SceneScanParameters']]],
  ['setnumberofimages',['setNumberOfImages',['../classvisiontransfer_1_1ImageSet.html#a5428c4ae638f460f9c3d21fe887e59b3',1,'visiontransfer::ImageSet']]],
  ['setoperationmode',['setOperationMode',['../classvisiontransfer_1_1SceneScanParameters.html#a3b4985e338735b299e368df00253a9b5',1,'visiontransfer::SceneScanParameters']]],
  ['setpixeldata',['setPixelData',['../classvisiontransfer_1_1ImageSet.html#a5c0e118361c82bd263dfc406d9c1b3a6',1,'visiontransfer::ImageSet']]],
  ['setpixelformat',['setPixelFormat',['../classvisiontransfer_1_1ImageSet.html#a80073b18dbfc5f365cefe3cbddaf2577',1,'visiontransfer::ImageSet']]],
  ['setqmatrix',['setQMatrix',['../classvisiontransfer_1_1ImageSet.html#ae5ae6618b9c5311d1635be21093f3660',1,'visiontransfer::ImageSet']]],
  ['setrawtransferdata',['setRawTransferData',['../classvisiontransfer_1_1ImageProtocol.html#acf1fded1ba98bf4633c0942fcb7bb960',1,'visiontransfer::ImageProtocol::setRawTransferData()'],['../classvisiontransfer_1_1ImageTransfer.html#aa1f9d84bcb785ba81f1e82a027011760',1,'visiontransfer::ImageTransfer::setRawTransferData()']]],
  ['setrawvalidbytes',['setRawValidBytes',['../classvisiontransfer_1_1ImageProtocol.html#a976034236aae33c8dd5de93eb7afefd5',1,'visiontransfer::ImageProtocol::setRawValidBytes()'],['../classvisiontransfer_1_1ImageTransfer.html#a1e567fc9ac8468714707a42a4dca85a0',1,'visiontransfer::ImageTransfer::setRawValidBytes()']]],
  ['setrowstride',['setRowStride',['../classvisiontransfer_1_1ImageSet.html#a4aa77ac2bc0655e7ec595e34b50bf678',1,'visiontransfer::ImageSet']]],
  ['setsaveautorecalibration',['setSaveAutoRecalibration',['../classvisiontransfer_1_1SceneScanParameters.html#a550499dcf377a8ab717d4bd87718170e',1,'visiontransfer::SceneScanParameters']]],
  ['setsequencenumber',['setSequenceNumber',['../classvisiontransfer_1_1ImageSet.html#af8c266658adcbd8ae18a8b888e71a103',1,'visiontransfer::ImageSet']]],
  ['setspecklefilteriterations',['setSpeckleFilterIterations',['../classvisiontransfer_1_1SceneScanParameters.html#a94a43ffbb20efbc840db3e17730c96b8',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingedgesensitivity',['setStereoMatchingEdgeSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#ad4a1461e2d499c004e0125f8649fa763',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp1edge',['setStereoMatchingP1Edge',['../classvisiontransfer_1_1SceneScanParameters.html#a6a4d92d9ce801cf53c90dac8c1775e3d',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp1noedge',['setStereoMatchingP1NoEdge',['../classvisiontransfer_1_1SceneScanParameters.html#adfe5a8c348020031031efd1564878c61',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp2edge',['setStereoMatchingP2Edge',['../classvisiontransfer_1_1SceneScanParameters.html#a009a6e41a47f976158fd208bfc4fdbe1',1,'visiontransfer::SceneScanParameters']]],
  ['setstereomatchingp2noedge',['setStereoMatchingP2NoEdge',['../classvisiontransfer_1_1SceneScanParameters.html#ac9ee7c8b4f5285b0c7c97d46747fd833',1,'visiontransfer::SceneScanParameters']]],
  ['setsubpixelfactor',['setSubpixelFactor',['../classvisiontransfer_1_1ImageSet.html#aecb0706993d4aaffc4fa4484217299f6',1,'visiontransfer::ImageSet']]],
  ['setsubpixeloptimizationroi',['setSubpixelOptimizationROI',['../classvisiontransfer_1_1SceneScanParameters.html#a0f209c7549fc9f8cec24c130479f9339',1,'visiontransfer::SceneScanParameters']]],
  ['setsubpixeloptimizationroienabled',['setSubpixelOptimizationROIEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a54e18840db98817a797f695b1065d9da',1,'visiontransfer::SceneScanParameters']]],
  ['settexturefilterenabled',['setTextureFilterEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a4feeed602b5f94c51c23762cb0bfc3af',1,'visiontransfer::SceneScanParameters']]],
  ['settexturefiltersensitivity',['setTextureFilterSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#a8d56622c330f6de6295cc1f37bb72387',1,'visiontransfer::SceneScanParameters']]],
  ['settimestamp',['setTimestamp',['../classvisiontransfer_1_1ImageSet.html#a622b4e710a864ba7d5e02d3a9aa5d52e',1,'visiontransfer::ImageSet']]],
  ['settransferbytes',['setTransferBytes',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#ac255246f81fee027387f5ab5fa96b207',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settransferdata',['setTransferData',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#aea6a2a2bf3002d258791bf5c988922c0',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settransferheader',['setTransferHeader',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#a432327932f1f7d3332d33c45f58e4584',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settransferimageset',['setTransferImageSet',['../classvisiontransfer_1_1ImageProtocol.html#a148db156661b027f549d79c9b0c4bf77',1,'visiontransfer::ImageProtocol::setTransferImageSet()'],['../classvisiontransfer_1_1ImageTransfer.html#a8edc6a52ff434963437e2beb7f90f200',1,'visiontransfer::ImageTransfer::setTransferImageSet()']]],
  ['settransfervalidbytes',['setTransferValidBytes',['../classvisiontransfer_1_1internal_1_1DataBlockProtocol.html#aabdc18b2c26fe1725516a29540e50e04',1,'visiontransfer::internal::DataBlockProtocol']]],
  ['settrigger0enabled',['setTrigger0Enabled',['../classvisiontransfer_1_1SceneScanParameters.html#a93435b2181cbc4f399c63398ef758674',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger0polarity',['setTrigger0Polarity',['../classvisiontransfer_1_1SceneScanParameters.html#a083f87291a40d190e2b31ec017e14ec5',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger0pulsewidth',['setTrigger0PulseWidth',['../classvisiontransfer_1_1SceneScanParameters.html#accb9b081e50f6673bea0c0bef0083367',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1enabled',['setTrigger1Enabled',['../classvisiontransfer_1_1SceneScanParameters.html#a71adf6d867815e42eca47de40c456414',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1offset',['setTrigger1Offset',['../classvisiontransfer_1_1SceneScanParameters.html#a3c61d2ca5d8c10ad266787b64ca8a8b7',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1polarity',['setTrigger1Polarity',['../classvisiontransfer_1_1SceneScanParameters.html#a17ec6dd230d5360cdf178f44be0833fe',1,'visiontransfer::SceneScanParameters']]],
  ['settrigger1pulsewidth',['setTrigger1PulseWidth',['../classvisiontransfer_1_1SceneScanParameters.html#ad514257e02a07e6f02fb53d59c842e67',1,'visiontransfer::SceneScanParameters']]],
  ['settriggerfrequency',['setTriggerFrequency',['../classvisiontransfer_1_1SceneScanParameters.html#acf85cda5fd69be6c6e4025414ce88870',1,'visiontransfer::SceneScanParameters']]],
  ['setuniquenesscheckenabled',['setUniquenessCheckEnabled',['../classvisiontransfer_1_1SceneScanParameters.html#a351292901d3e1a4768e8f4d6153c782b',1,'visiontransfer::SceneScanParameters']]],
  ['setuniquenesschecksensitivity',['setUniquenessCheckSensitivity',['../classvisiontransfer_1_1SceneScanParameters.html#a4b6455fe91fe83436dccbd79df4fbcdc',1,'visiontransfer::SceneScanParameters']]],
  ['setwidth',['setWidth',['../classvisiontransfer_1_1ImageSet.html#a251f5c8c7c0a55286b967e91a2e18e4a',1,'visiontransfer::ImageSet']]],
  ['startservice',['startService',['../classvisiontransfer_1_1internal_1_1ClientSideDataChannelIMUBNO080.html#aa9f3de8c0c6ff0f13bab9de62f8a3701',1,'visiontransfer::internal::ClientSideDataChannelIMUBNO080::startService()'],['../classvisiontransfer_1_1internal_1_1DataChannel.html#ae3ae34aa52708797caa3e68789ea7374',1,'visiontransfer::internal::DataChannel::startService()']]]
];
